/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#include <stdio.h>
#include <setjmp.h>
#include <stdlib.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyObject_HSlice__OMpduBN65LLptEIzH4Rd9cw tyObject_HSlice__OMpduBN65LLptEIzH4Rd9cw;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct Exception Exception;
typedef struct RootObj RootObj;
typedef struct tySequence__QbmGqFaLnb1IWWToREeaIA tySequence__QbmGqFaLnb1IWWToREeaIA;
typedef struct TSafePoint TSafePoint;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_ESuggestDone__0sxcG9bses4KEF5Ub8L9ae1Q tyObject_ESuggestDone__0sxcG9bses4KEF5Ub8L9ae1Q;
typedef struct tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA;
typedef struct tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU8 tyEnum_ForegroundColor__avKgWVVKiIc89c9aKDsFLd7w;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
struct tyObject_HSlice__OMpduBN65LLptEIzH4Rd9cw {
tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ a;
tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ b;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
typedef N_CLOSURE_PTR(void, TM__F6BaKnf3IVC9biwXXfTyA9ag_4) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity);
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
typedef NimStringDesc* tyArray__24KAM9afIUgUaqBaEBB6r9bg[3];
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
typedef NU8 tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
typedef N_CLOSURE_PTR(void, TM__F6BaKnf3IVC9biwXXfTyA9ag_13) (NimStringDesc* output);
typedef NU8 tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
typedef NU8 tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef NU16 tySet_tyEnum_Style__IfhGTpNOgg3EytKq9c3Vnwg;
typedef NU8 tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA;
typedef NU8 tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NimStringDesc* tyArray__kCuVL45VApJthfOamSfyoA[107];
typedef N_CLOSURE_PTR(void, TM__F6BaKnf3IVC9biwXXfTyA9ag_19) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity);
typedef NimStringDesc* tyArray__yt5VDPNtUGx9cBkOVakHwdQ[6];
struct RootObj {
TNimType* m_type;
};
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__QbmGqFaLnb1IWWToREeaIA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef NU8 tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w;
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef N_CLOSURE_PTR(void, TM__F6BaKnf3IVC9biwXXfTyA9ag_24) (NimStringDesc* output);
typedef NimStringDesc* tyArray__sMpvt1sOxOJ3LFGulnbeMQ[4];
typedef N_CLOSURE_PTR(void, TM__F6BaKnf3IVC9biwXXfTyA9ag_27) (NimStringDesc* output);
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef N_CLOSURE_PTR(void, TM__F6BaKnf3IVC9biwXXfTyA9ag_33) (NimStringDesc* output);
typedef NU8 tySet_tyEnum_MsgFlag__20vXBZGIzyW7fngd9aGsclQ;
typedef NU8 tyEnum_MsgFlag__20vXBZGIzyW7fngd9aGsclQ;
typedef N_CLOSURE_PTR(void, TM__F6BaKnf3IVC9biwXXfTyA9ag_34) (NimStringDesc* output);
struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ {
  RootObj Sup;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* left;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* right;
NI L;
NimStringDesc* data;
};
typedef N_CLOSURE_PTR(void, TM__F6BaKnf3IVC9biwXXfTyA9ag_42) (NimStringDesc* output);
struct tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ {
  Exception Sup;
};
struct tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA {
  tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ Sup;
};
struct tyObject_ESuggestDone__0sxcG9bses4KEF5Ub8L9ae1Q {
  tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA Sup;
};
typedef NU8 tyEnum_BinaryPrefixMode__9aq8p9cHh4TxM4kldzuu2GZA;
typedef NU8 tyEnum_FloatFormatMode__alaW5GAGZvqS9bWFnNLXFuA;
typedef NimStringDesc* tyArray__ucDUDWdKfioXQrN9bCbG29bg[12];
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__QbmGqFaLnb1IWWToREeaIA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA data[SEQ_DECL_SIZE];
};
static N_INLINE(NIM_BOOL, contains__msgs_963)(tyObject_HSlice__OMpduBN65LLptEIzH4Rd9cw s, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ value);
static N_INLINE(tyObject_HSlice__OMpduBN65LLptEIzH4Rd9cw, dotdot___msgs_902)(tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ a, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ b);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, writeContext__msgs_1011)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastinfo);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___msgs_1003)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw a, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatVarargs)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, concat__msgs_415)(NimStringDesc** strings, NI stringsLen_0);
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_629)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toMsgFilename__msgs_612)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFilenameOption__msgs_600)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx, tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w opt);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__msgs_548)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toProjPath__msgs_540)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, canonicalImportAux__options_4639)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* file);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, noslastPathPart)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCountString)(NimStringDesc* s, NimStringDesc* sub, NIM_BOOL overlapping);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_167)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, flushDot__msgs_17)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, write__systemZio_205)(FILE* f, NimStringDesc* s);
static N_INLINE(void, writeLine__msgs_442)(FILE* f, NimStringDesc** x, NI xLen_0);
N_LIB_PRIVATE N_NIMCALL(void, flushFile__systemZio_226)(FILE* f);
N_LIB_PRIVATE N_NIMCALL(void, setStyle__pureZterminal_313)(FILE* f, tySet_tyEnum_Style__IfhGTpNOgg3EytKq9c3Vnwg style);
N_LIB_PRIVATE N_NIMCALL(void, resetAttributes__pureZterminal_280)(FILE* f);
static N_INLINE(NIM_BOOL, hasWarn__options_570)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA note);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasHint__options_530)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA note);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getMessageStr__msgs_785)(tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, msgKindToString__msgs_782)(tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ kind);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, ignoreMsgBecauseOfIdeTools__msgs_1076)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg);
N_LIB_PRIVATE N_NIMCALL(void, msgWrite__msgs_759)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getSurroundingSrc__msgs_1116)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, sourceLine__msgs_1111)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw i);
N_LIB_PRIVATE N_NIMCALL(NI, numLines__msgs_1100)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPathConsiderDirty__msgs_581)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
static N_INLINE(NIM_BOOL, isEmpty__options_4492)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(FILE*, open__systemZio_430)(NimStringDesc* filename, tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w mode, NI bufSize);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, readLine__systemZio_238)(FILE* f, NimStringDesc** line);
N_LIB_PRIVATE N_NIMCALL(void, addSourceLine__msgs_1092)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx, NimStringDesc* line);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5258)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(void, close__systemZio_217)(FILE* f);
N_LIB_PRIVATE N_NIMCALL(void, nimLeaveFinally)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isObj)(TNimType* obj, TNimType* subclass);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(void, popCurrentException)(void);
static N_INLINE(NimStringDesc*, spaces__pureZstrutils_1029)(NI n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuRepeatChar)(NIM_CHAR c, NI count);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(void, setForegroundColor__pureZterminal_387)(FILE* f, tyEnum_ForegroundColor__avKgWVVKiIc89c9aKDsFLd7w fg, NIM_BOOL bright);
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
N_LIB_PRIVATE N_NIMCALL(void, handleError__msgs_880)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, NimStringDesc* s, NIM_BOOL ignoreMsg);
N_LIB_PRIVATE N_NIMCALL(void, log__msgs_796)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, open__systemZio_389)(FILE** f, NimStringDesc* filename, tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w mode, NI bufSize);
static N_INLINE(NimStringDesc*, slash___pureZos_121)(NimStringDesc* head, NimStringDesc* tail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosjoinPath)(NimStringDesc* head, NimStringDesc* tail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetHomeDir)(void);
N_LIB_PRIVATE N_NIMCALL(void, quit__msgs_803)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_2292)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__systemZassertions_56)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(void, quit__system_7166)(NimStringDesc* errormsg, NI errorcode) __attribute__((noreturn));
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, stackTraceAvailable__system_2747)(void);
N_LIB_PRIVATE N_NIMCALL(void, writeStackTrace__system_2167)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, createDocLink__lineinfos_6)(NimStringDesc* urlSuffix);
N_LIB_PRIVATE N_NOINLINE(void, raiseRecoverableError__lineinfos_262)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(void, msgWriteln__msgs_657)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* s, tySet_tyEnum_MsgFlag__20vXBZGIzyW7fngd9aGsclQ flags);
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__msgs_127)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename, NIM_BOOL* isKnownFile);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, canonicalizePath__options_4119)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* path);
static N_INLINE(void, shallow__system_7426)(NimStringDesc** s);
N_NIMCALL(NimStringDesc*, mnewString)(NI len);
N_LIB_PRIVATE N_NIMCALL(void, forceCopy__strutils50_10)(NimStringDesc** result, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(void, canonicalCase__msgs_67)(NimStringDesc** path);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__msgs_114)(tyObject_Table__9cHFtxtpgztIcDsypRz9byKw t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(NI32*, X5BX5D___msgs_233)(tyObject_Table__9cHFtxtpgztIcDsypRz9byKw* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, newFileInfo__msgs_59)(NimStringDesc* fullPath, NimStringDesc* projPath, tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w* Result);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosextractFilename)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, makeCString__msgs_50)(NimStringDesc* s);
static N_INLINE(NF, toFloat__system_1702)(NI i);
static N_INLINE(void, toCChar__msgs_47)(NIM_CHAR c, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuToOctal)(NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(void, add__ropes_159)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** a, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, rope__ropes_109)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, relativeTo__pathutils_133)(NimStringDesc* fullPath, NimStringDesc* baseFilename, NIM_CHAR sep);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___lineinfos_391)(tyObject_Table__9cHFtxtpgztIcDsypRz9byKw* t, NimStringDesc* key, NI32 val);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuStartsWith)(NimStringDesc* s, NimStringDesc* prefix);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuEndsWith)(NimStringDesc* s, NimStringDesc* suffix);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e, NCSTRING ename, NCSTRING procname, NCSTRING filename, NI line);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosexpandFilename)(NimStringDesc* filename);
static N_INLINE(NIM_BOOL, lteqpercent___system_985)(NI x, NI y);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, formatSize__pureZstrutils_1967)(NI64 bytes, NIM_CHAR decimalSep, tyEnum_BinaryPrefixMode__9aq8p9cHh4TxM4kldzuu2GZA prefix, NIM_BOOL includeSpace);
N_LIB_PRIVATE N_NIMCALL(NI, getMaxMem__system_5236)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_3)(NI x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuformatFloat)(NF f, tyEnum_FloatFormatMode__alaW5GAGZvqS9bWFnNLXFuA format, NI precision, NIM_CHAR decimalSep);
N_LIB_PRIVATE N_NIMCALL(NF, epochTime__pureZtimes_3608)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___options_4370)(NimStringDesc* x);
static N_INLINE(NIM_BOOL, isEmpty__options_4084)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, absOutFile__options_4073)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
extern TNimType NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_;
static NIM_CONST tyProc__2bM7rNPFiQD9bOvwFI49bKLQ TM__F6BaKnf3IVC9biwXXfTyA9ag_2 = {NIM_NIL,NIM_NIL};
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_3, "template/generic instantiation from here", 40);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_5, "template/generic instantiation of `$1` from here", 48);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_6, "command line", 12);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_7, "\?\?\?", 3);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_8, "..", 2);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_9, "(", 1);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_10, ", ", 2);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_11, ")", 1);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_12, " ", 1);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_14, "\012", 1);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_15, "Error: ", 7);
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_16, "Warning: ", 9);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_17, "Hint: ", 6);
extern NIM_CONST tyArray__kCuVL45VApJthfOamSfyoA MsgKindToStr__lineinfos_120;
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_18, " [$1]", 5);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_20, ".", 1);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_21, "\012  ", 3);
extern TNimType NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_;
extern TNimType NTIioerror__5GCiDuy5Wsuc9an2QZvqgIA_;
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_25, " compiler msg initiated here", 28);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_26, "MsgOrigin", 9);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_28, "nimsuggest.log", 14);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_29, "nimDebug", 8);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_30, "options.nim(645, 14) `false` ", 29);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_31, "No stack traceback available\012To create a stacktrace, rerun compilation with \'./koch temp $1 <file>\', see $2 for details", 119);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_32, "intern.html#debugging-the-compiler", 34);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_35, "Warnings:", 9);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_36, "  [$1] $2", 9);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_37, "x", 1);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_38, "Hints:", 6);
extern TNimType NTIoserror__THeHlGxHorUQ17FON5jY0g_;
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_40, "\"", 1);
extern TNimType NTIseqLtfileinfoT__8rKxBHaz7QqNR9a4WIZqqqQ_;
extern TNimType NTItfileinfo__2PBRRPxvvEH2sQ9cRi19bh7w_;
N_LIB_PRIVATE NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw gCmdLineInfo__msgs_414 = {((NU16) 1), ((NI16) 1), ((NI32) -3)}
;
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_41, ".nim", 4);
extern TNimType NTIseqLtupleLinfo58tlineinfo_detail58stringTT__mIo9bZUsotCEUUtEGNhYmaA_;
extern TNimType NTIrefesuggestdone__NT9aUkpr32D3T9aXH5k1dBXg_;
extern TNimType NTIesuggestdone__0sxcG9bses4KEF5Ub8L9ae1Q_;
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_43, "suggest done", 12);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_44, " peakmem", 8);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_45, "gc: $#; ", 8);
extern TNimType NTItgcmode__yHeclYqeKaCEfMHNbcWn4w_;
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_46, "threads: on; ", 13);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_47, "opt: ", 5);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_48, "speed", 5);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_49, "size", 4);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_50, "none (DEBUG BUILD, `-d:release` generates faster code)", 54);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_51, "danger", 6);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_52, " -d:danger", 10);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_53, "release", 7);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_54, " -d:release", 11);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_55, "; options:", 10);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_56, "unknownOutput", 13);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_57, "build", 5);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_58, "loc", 3);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_59, "sec", 3);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_60, "mem", 3);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_61, "project", 7);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_62, "output", 6);
STRING_LITERAL(TM__F6BaKnf3IVC9biwXXfTyA9ag_64, "/home/runner/work/nightlies/nightlies/nim/compiler/msgs.nim", 59);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__F6BaKnf3IVC9biwXXfTyA9ag_63 = {((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_64),
((NI) 713),
((NI) 12)}
;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5211;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
static N_INLINE(NIM_BOOL, contains__msgs_963)(tyObject_HSlice__OMpduBN65LLptEIzH4Rd9cw s, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ value) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (s.a <= value);
	if (!(T1_)) goto LA2_;
	T1_ = (value <= s.b);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(tyObject_HSlice__OMpduBN65LLptEIzH4Rd9cw, dotdot___msgs_902)(tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ a, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ b) {
	tyObject_HSlice__OMpduBN65LLptEIzH4Rd9cw result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__OMpduBN65LLptEIzH4Rd9cw));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__OMpduBN65LLptEIzH4Rd9cw));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___msgs_1003)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw a, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw b) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (a.line == b.line);
	if (!(T1_)) goto LA2_;
	T1_ = (a.fileIndex == b.fileIndex);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, concat__msgs_415)(NimStringDesc** strings, NI stringsLen_0) {
	NimStringDesc* result;
	NI totalLen;
	result = NIM_NIL;
	totalLen = ((NI) 0);
	{
		NimStringDesc** s;
		NI i;
		s = (NimStringDesc**)0;
		i = ((NI) 0);
		{
			while (1) {
				if (!(i < stringsLen_0)) goto LA3;
				s = (&strings[i]);
				totalLen += ((*s) ? (*s)->Sup.len : 0);
				i += ((NI) 1);
			} LA3: ;
		}
	}
	result = rawNewString(((NI) (totalLen)));
	{
		NimStringDesc** s_2;
		NI i_2;
		s_2 = (NimStringDesc**)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < stringsLen_0)) goto LA6;
				s_2 = (&strings[i_2]);
				result = resizeString(result, ((*s_2) ? (*s_2)->Sup.len : 0) + 0);
appendString(result, (*s_2));
				i_2 += ((NI) 1);
			} LA6: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__msgs_548)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (fileIdx < ((NI32) 0));
		if (T3_) goto LA4_;
		T3_ = (conf == ((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			if (!(fileIdx == ((NI32) -3))) goto LA9_;
			result = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_6));
		}
		goto LA7_;
		LA9_: ;
		{
			result = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_7));
		}
		LA7_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		result = copyString((*conf).m.fileInfos->data[fileIdx].fullPath);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toProjPath__msgs_540)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (fileIdx < ((NI32) 0));
		if (T3_) goto LA4_;
		T3_ = (conf == ((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			if (!(fileIdx == ((NI32) -3))) goto LA9_;
			result = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_6));
		}
		goto LA7_;
		LA9_: ;
		{
			result = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_7));
		}
		LA7_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		result = copyString((*conf).m.fileInfos->data[fileIdx].projPath);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFilenameOption__msgs_600)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx, tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w opt) {
	NimStringDesc* result;
	result = NIM_NIL;
	switch (opt) {
	case ((tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w) 0):
	{
		result = toFullPath__msgs_548(conf, fileIdx);
	}
	break;
	case ((tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w) 1):
	{
		result = toProjPath__msgs_540(conf, fileIdx);
	}
	break;
	case ((tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w) 2):
	{
		NimStringDesc* absPath;
		absPath = toFullPath__msgs_548(conf, fileIdx);
		result = canonicalImportAux__options_4639(conf, absPath);
	}
	break;
	case ((tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w) 4):
	{
		NimStringDesc* T5_;
		T5_ = NIM_NIL;
		T5_ = toProjPath__msgs_540(conf, fileIdx);
		result = noslastPathPart(T5_);
	}
	break;
	case ((tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w) 3):
	{
		NimStringDesc* absPath_2;
		NimStringDesc* relPath;
		absPath_2 = toFullPath__msgs_548(conf, fileIdx);
		relPath = toProjPath__msgs_540(conf, fileIdx);
		{
			NIM_BOOL T9_;
			NI T11_;
			T9_ = (NIM_BOOL)0;
			T9_ = ((absPath_2 ? absPath_2->Sup.len : 0) < (relPath ? relPath->Sup.len : 0));
			if (T9_) goto LA10_;
			T11_ = (NI)0;
			T11_ = nsuCountString(relPath, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_8), NIM_FALSE);
			T9_ = (((NI) 2) < T11_);
			LA10_: ;
			if (!T9_) goto LA12_;
			result = copyString(absPath_2);
		}
		goto LA7_;
		LA12_: ;
		{
			result = copyString(relPath);
		}
		LA7_: ;
	}
	break;
	case ((tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w) 5):
	{
		{
			if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 31))&63U)))!=0)) goto LA18_;
			result = toFilenameOption__msgs_600(conf, fileIdx, ((tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w) 0));
		}
		goto LA16_;
		LA18_: ;
		{
			result = toFilenameOption__msgs_600(conf, fileIdx, ((tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w) 4));
		}
		LA16_: ;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toMsgFilename__msgs_612)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = toFilenameOption__msgs_600(conf, fileIdx, (*conf).filenameOption);
	return result;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x) {
	addInt__stdZprivateZdigitsutils_167(result, ((NI64) (x)));
}
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_629)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = toMsgFilename__msgs_612(conf, info.fileIndex);
	result = resizeString(result, (T1_ ? T1_->Sup.len : 0) + 0);
appendString(result, T1_);
	{
		if (!(((NI) 0) < ((NI) (info.line)))) goto LA4_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_9));
		addInt__stdZprivateZdigitsutils_189((&result), ((NI) (info.line)));
		{
			if (!(((NI) 0) < (NI)(((NI) (info.col)) + ((NI) 1)))) goto LA8_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_10));
			addInt__stdZprivateZdigitsutils_189((&result), (NI)(((NI) (info.col)) + ((NI) 1)));
		}
		LA8_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_11));
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, flushDot__msgs_17)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	FILE* stdOrr;
	tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA stdOrrKind;
	{
		if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 24))&63U)))!=0)) goto LA3_;
		stdOrr = stdout;
	}
	goto LA1_;
	LA3_: ;
	{
		stdOrr = stderr;
	}
	LA1_: ;
	{
		if (!(stdOrr == stdout)) goto LA8_;
		stdOrrKind = ((tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA) 0);
	}
	goto LA6_;
	LA8_: ;
	{
		stdOrrKind = ((tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA) 1);
	}
	LA6_: ;
	{
		if (!(((*conf).lastMsgWasDot &((NU8)1<<((NU)(stdOrrKind)&7U)))!=0)) goto LA13_;
		(*conf).lastMsgWasDot &= ~(((NU8)1) << ((stdOrrKind) & 7));
		write__systemZio_205(stdOrr, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_14));
	}
	LA13_: ;
}
static N_INLINE(void, writeLine__msgs_442)(FILE* f, NimStringDesc** x, NI xLen_0) {
	{
		NimStringDesc** i;
		NI i_2;
		i = (NimStringDesc**)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < xLen_0)) goto LA3;
				i = (&x[i_2]);
				write__systemZio_205(f, (*i));
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	write__systemZio_205(f, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_14));
}
N_LIB_PRIVATE N_NIMCALL(void, writeContext__msgs_1011)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastinfo) {
	tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
	info = lastinfo;
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*conf).m.msgContext ? (*conf).m.msgContext->Sup.len : 0);
		colontmp_ = T2_;
		i_2 = ((NI) 0);
		{
			while (1) {
				tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ context;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				nimZeroMem((void*)(&context), sizeof(tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ));
				context.Field0 = (*conf).m.msgContext->data[i].Field0;
				context.Field1 = (*conf).m.msgContext->data[i].Field1;
				{
					NIM_BOOL T7_;
					NIM_BOOL T8_;
					NIM_BOOL T10_;
					T7_ = (NIM_BOOL)0;
					T8_ = (NIM_BOOL)0;
					T8_ = eqeq___msgs_1003(context.Field0, lastinfo);
					T7_ = !(T8_);
					if (!(T7_)) goto LA9_;
					T10_ = (NIM_BOOL)0;
					T10_ = eqeq___msgs_1003(context.Field0, info);
					T7_ = !(T10_);
					LA9_: ;
					if (!T7_) goto LA11_;
					{
						if (!!(((*conf).structuredErrorHook.ClP_0 == TM__F6BaKnf3IVC9biwXXfTyA9ag_2.ClP_0 && (*conf).structuredErrorHook.ClE_0 == TM__F6BaKnf3IVC9biwXXfTyA9ag_2.ClE_0))) goto LA15_;
						(*conf).structuredErrorHook.ClE_0? (*conf).structuredErrorHook.ClP_0(conf, context.Field0, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_3), ((tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg) 0), (*conf).structuredErrorHook.ClE_0):((TM__F6BaKnf3IVC9biwXXfTyA9ag_4)((*conf).structuredErrorHook.ClP_0))(conf, context.Field0, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_3), ((tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg) 0));
					}
					goto LA13_;
					LA15_: ;
					{
						NimStringDesc* message;
						{
							if (!((context.Field1 ? context.Field1->Sup.len : 0) == 0)) goto LA20_;
							message = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_3));
						}
						goto LA18_;
						LA20_: ;
						{
							tyArray__nHXaesL0DJZHyVS07ARPRA T23_;
							nimZeroMem((void*)T23_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
							T23_[0] = copyString(context.Field1);
							message = nsuFormatVarargs(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_5), T23_, 1);
						}
						LA18_: ;
						{
							tyArray__24KAM9afIUgUaqBaEBB6r9bg T28_;
							NimStringDesc* T29_;
							if (!!(((*conf).writelnHook.ClP_0 == 0))) goto LA26_;
							nimZeroMem((void*)T28_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
							T28_[0] = toFileLineCol__msgs_629(conf, context.Field0);
							T28_[1] = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_12));
							T28_[2] = copyString(message);
							T29_ = NIM_NIL;
							T29_ = concat__msgs_415(T28_, 3);
							(*conf).writelnHook.ClE_0? (*conf).writelnHook.ClP_0(T29_, (*conf).writelnHook.ClE_0):((TM__F6BaKnf3IVC9biwXXfTyA9ag_13)((*conf).writelnHook.ClP_0))(T29_);
						}
						goto LA24_;
						LA26_: ;
						{
							if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 24))&63U)))!=0)) goto LA31_;
							{
								tyArray__24KAM9afIUgUaqBaEBB6r9bg T37_;
								if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ) 0))&7U)))!=0)) goto LA35_;
								flushDot__msgs_17(conf);
								nimZeroMem((void*)T37_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
								T37_[0] = toFileLineCol__msgs_629(conf, context.Field0);
								T37_[1] = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_12));
								T37_[2] = copyString(message);
								writeLine__msgs_442(stdout, T37_, 3);
								flushFile__systemZio_226(stdout);
							}
							LA35_: ;
						}
						goto LA24_;
						LA31_: ;
						{
							if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ) 1))&7U)))!=0)) goto LA39_;
							flushDot__msgs_17(conf);
							{
								NimStringDesc* T45_;
								if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 22))&63U)))!=0)) goto LA43_;
								setStyle__pureZterminal_313(stderr, 1);
								T45_ = NIM_NIL;
								T45_ = toFileLineCol__msgs_629(conf, context.Field0);
								write__systemZio_205(stderr, T45_);
								write__systemZio_205(stderr, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_12));
								resetAttributes__pureZterminal_280(stderr);
								write__systemZio_205(stderr, message);
								resetAttributes__pureZterminal_280(stderr);
								write__systemZio_205(stderr, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_14));
							}
							goto LA41_;
							LA43_: ;
							{
								tyArray__24KAM9afIUgUaqBaEBB6r9bg T47_;
								nimZeroMem((void*)T47_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
								T47_[0] = toFileLineCol__msgs_629(conf, context.Field0);
								T47_[1] = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_12));
								T47_[2] = copyString(message);
								writeLine__msgs_442(stderr, T47_, 3);
							}
							LA41_: ;
						}
						goto LA24_;
						LA39_: ;
						LA24_: ;
					}
					LA13_: ;
				}
				LA11_: ;
				info = context.Field0;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
}
static N_INLINE(NIM_BOOL, hasWarn__options_570)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA note) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 13))&31U)))!=0);
	if (!(T1_)) goto LA2_;
	T1_ = (((*conf).notes[(NU)((note- 17))>>3] &(1U<<((NU)((note- 17))&7U)))!=0);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, msgKindToString__msgs_782)(tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ kind) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = copyString(MsgKindToStr__lineinfos_120[(kind)- 0]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getMessageStr__msgs_785)(tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	tyArray__nHXaesL0DJZHyVS07ARPRA T2_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = msgKindToString__msgs_782(msg);
	nimZeroMem((void*)T2_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
	T2_[0] = copyString(arg);
	result = nsuFormatOpenArray(T1_, T2_, 1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, ignoreMsgBecauseOfIdeTools__msgs_1076)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = (((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15) <= msg);
	if (!(T2_)) goto LA3_;
	T2_ = ((*conf).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 11));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = !((((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 29))&63U)))!=0));
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, msgWrite__msgs_759)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* s) {
	{
		FILE* stdOrr;
		tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA T10_;
		if (!!(((*conf).m.errorOutputs == 0))) goto LA3_;
		{
			if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 24))&63U)))!=0)) goto LA7_;
			stdOrr = stdout;
		}
		goto LA5_;
		LA7_: ;
		{
			stdOrr = stderr;
		}
		LA5_: ;
		write__systemZio_205(stdOrr, s);
		flushFile__systemZio_226(stdOrr);
		T10_ = (tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA)0;
		{
			if (!(stdOrr == stdout)) goto LA13_;
			T10_ = ((tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA) 0);
		}
		goto LA11_;
		LA13_: ;
		{
			T10_ = ((tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA) 1);
		}
		LA11_: ;
		(*conf).lastMsgWasDot |= ((NU8)1)<<((T10_) & 7);
	}
	LA3_: ;
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__system_2565;
	excHandler__system_2565 = s;
}
static N_INLINE(NIM_BOOL, isEmpty__options_4492)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPathConsiderDirty__msgs_581)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		if (!(fileIdx < ((NI32) 0))) goto LA3_;
		{
			if (!(fileIdx == ((NI32) -3))) goto LA7_;
			result = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_6));
		}
		goto LA5_;
		LA7_: ;
		{
			result = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_7));
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T11_;
		T11_ = (NIM_BOOL)0;
		T11_ = isEmpty__options_4492((*conf).m.fileInfos->data[fileIdx].dirtyFile);
		if (!!(T11_)) goto LA12_;
		result = copyString((*conf).m.fileInfos->data[fileIdx].dirtyFile);
	}
	goto LA1_;
	LA12_: ;
	{
		result = copyString((*conf).m.fileInfos->data[fileIdx].fullPath);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5302)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5264)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5307)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5258((&gch__system_5211.zct), c);
}
static N_INLINE(void, decRef__system_5309)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5307(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5264(src);
		incRef__system_5302(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5264((*dest));
		decRef__system_5309(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5264(p);
	decRef__system_5309(T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, addSourceLine__msgs_1092)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx, NimStringDesc* line) {
	NI T1_;
	NimStringDesc* T2_;
	asgnRef((void**) (&(*conf).m.fileInfos->data[fileIdx].lines), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).m.fileInfos->data[fileIdx].lines), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
	T1_ = (*conf).m.fileInfos->data[fileIdx].lines->Sup.len++;
	T2_ = NIM_NIL;
	T2_ = (*conf).m.fileInfos->data[fileIdx].lines->data[T1_]; (*conf).m.fileInfos->data[fileIdx].lines->data[T1_] = copyStringRC1(line);
	if (T2_) nimGCunrefNoCycle(T2_);
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__system_2565 = (*excHandler__system_2565).prev;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = NIM_NIL;
	result = currException__system_2566;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	asgnRef((void**) (&currException__system_2566), (*currException__system_2566).up);
}
N_LIB_PRIVATE N_NIMCALL(NI, numLines__msgs_1100)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*conf).m.fileInfos->data[fileIdx].lines ? (*conf).m.fileInfos->data[fileIdx].lines->Sup.len : 0);
	result = T1_;
	{
		TSafePoint TM__F6BaKnf3IVC9biwXXfTyA9ag_22;
		NI T14_;
		if (!(result == ((NI) 0))) goto LA4_;
		pushSafePoint(&TM__F6BaKnf3IVC9biwXXfTyA9ag_22);
		TM__F6BaKnf3IVC9biwXXfTyA9ag_22.status = setjmp(TM__F6BaKnf3IVC9biwXXfTyA9ag_22.context);
		if (TM__F6BaKnf3IVC9biwXXfTyA9ag_22.status == 0) {
		{
			NimStringDesc* line;
			NimStringDesc* colontmp_;
			FILE* f;
			TSafePoint TM__F6BaKnf3IVC9biwXXfTyA9ag_23;
			NimStringDesc* res;
			line = NIM_NIL;
			colontmp_ = NIM_NIL;
			colontmp_ = toFullPathConsiderDirty__msgs_581(conf, fileIdx);
			f = open__systemZio_430(colontmp_, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 0), ((NI) 8000));
			pushSafePoint(&TM__F6BaKnf3IVC9biwXXfTyA9ag_23);
			TM__F6BaKnf3IVC9biwXXfTyA9ag_23.status = setjmp(TM__F6BaKnf3IVC9biwXXfTyA9ag_23.context);
			if (TM__F6BaKnf3IVC9biwXXfTyA9ag_23.status == 0) {
			res = rawNewString(((NI) 80));
			{
				while (1) {
					NIM_BOOL T9_;
					T9_ = (NIM_BOOL)0;
					T9_ = readLine__systemZio_238(f, (&res));
					if (!T9_) goto LA8;
					line = res;
					addSourceLine__msgs_1092(conf, fileIdx, line);
				} LA8: ;
			}
			popSafePoint();
			}
			else {
				popSafePoint();
			}
			{
				close__systemZio_217(f);
				if (TM__F6BaKnf3IVC9biwXXfTyA9ag_23.status != 0) nimLeaveFinally();
			}
			if (TM__F6BaKnf3IVC9biwXXfTyA9ag_23.status != 0) reraiseException();
		}
		popSafePoint();
		}
		else {
			popSafePoint();
			if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIioerror__5GCiDuy5Wsuc9an2QZvqgIA_))) {
				TM__F6BaKnf3IVC9biwXXfTyA9ag_22.status = 0;
				popCurrentException();
			}
		}
		if (TM__F6BaKnf3IVC9biwXXfTyA9ag_22.status != 0) reraiseException();
		T14_ = ((*conf).m.fileInfos->data[fileIdx].lines ? (*conf).m.fileInfos->data[fileIdx].lines->Sup.len : 0);
		result = T14_;
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, sourceLine__msgs_1111)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw i) {
	NimStringDesc* result;
	NI num;
{	result = NIM_NIL;
	{
		if (!(i.fileIndex < ((NI32) 0))) goto LA3_;
		result = ((NimStringDesc*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	num = numLines__msgs_1100(conf, i.fileIndex);
	{
		if (!(num < ((NI) (i.line)))) goto LA7_;
		result = ((NimStringDesc*) NIM_NIL);
		goto BeforeRet_;
	}
	LA7_: ;
	result = copyString((*conf).m.fileInfos->data[i.fileIndex].lines->data[(NI)(((NI) (i.line)) - ((NI) 1))]);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringDesc*, spaces__pureZstrutils_1029)(NI n) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = nsuRepeatChar(32, n);
	return result;
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getSurroundingSrc__msgs_1116)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		NimStringDesc* T8_;
		NimStringDesc* T9_;
		T3_ = (NIM_BOOL)0;
		T3_ = hasHint__options_530(conf, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 96));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = eqeq___msgs_1003(info, unknownLineInfo__lineinfos_284);
		T3_ = !(T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		T8_ = NIM_NIL;
		T9_ = NIM_NIL;
		T9_ = sourceLine__msgs_1111(conf, info);
		T8_ = rawNewString((T9_ ? T9_->Sup.len : 0) + 3);
appendString(T8_, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_21));
appendString(T8_, T9_);
		result = T8_;
		{
			NimStringDesc* T14_;
			NimStringDesc* T15_;
			if (!(((NI16) 0) <= info.col)) goto LA12_;
			T14_ = NIM_NIL;
			T15_ = NIM_NIL;
			T15_ = spaces__pureZstrutils_1029(((NI) (info.col)));
			T14_ = rawNewString((T15_ ? T15_->Sup.len : 0) + 4);
appendString(T14_, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_21));
appendString(T14_, T15_);
appendChar(T14_, 94);
			result = resizeString(result, (T14_ ? T14_->Sup.len : 0) + 0);
appendString(result, T14_);
		}
		LA12_: ;
	}
	LA6_: ;
	return result;
}
static N_INLINE(NimStringDesc*, toFileLineCol__msgs_625)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_9));
		addInt__stdZprivateZdigitsutils_189((&result), info.Field1);
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_10));
			addInt__stdZprivateZdigitsutils_189((&result), (NI)(info.Field2 + ((NI) 1)));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_11));
	}
	LA3_: ;
	return result;
}
static N_INLINE(NimStringDesc*, slash___pureZos_121)(NimStringDesc* head, NimStringDesc* tail) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = nosjoinPath(head, tail);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, log__msgs_796)(NimStringDesc* s) {
	FILE* f;
	f = (FILE*)0;
	{
		NimStringDesc* T3_;
		NimStringDesc* T4_;
		NIM_BOOL T5_;
		tyArray__nHXaesL0DJZHyVS07ARPRA T8_;
		T3_ = NIM_NIL;
		T3_ = nosgetHomeDir();
		T4_ = NIM_NIL;
		T4_ = slash___pureZos_121(T3_, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_28));
		T5_ = (NIM_BOOL)0;
		T5_ = open__systemZio_389(&f, T4_, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 4), ((NI) -1));
		if (!T5_) goto LA6_;
		nimZeroMem((void*)T8_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T8_[0] = copyString(s);
		writeLine__msgs_442(f, T8_, 1);
		close__systemZio_217(f);
	}
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, quit__msgs_803)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isDefined__options_2292(conf, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_29));
		if (!T3_) goto LA4_;
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = isDefined__options_2292(conf, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_29));
			if (!T8_) goto LA9_;
			{
				NimStringDesc* T15_;
				if (!NIM_TRUE) goto LA13_;
				T15_ = NIM_NIL;
				T15_ = rawNewString((reprEnum((NI)msg, (&NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_)) ? reprEnum((NI)msg, (&NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_))->Sup.len : 0) + 29);
appendString(T15_, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_30));
appendString(T15_, reprEnum((NI)msg, (&NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_)));
				failedAssertImpl__systemZassertions_56(T15_);
			}
			LA13_: ;
		}
		goto LA6_;
		LA9_: ;
		{
			quit__system_7166(reprEnum((NI)msg, (&NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_)), ((NI) 1));
		}
		LA6_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		NIM_BOOL T18_;
		NIM_BOOL T19_;
		T18_ = (NIM_BOOL)0;
		T19_ = (NIM_BOOL)0;
		T19_ = NIM_FALSE;
		if (T19_) goto LA20_;
		T19_ = (msg == ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 2));
		LA20_: ;
		T18_ = T19_;
		if (T18_) goto LA21_;
		T18_ = hasHint__options_530(conf, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 98));
		LA21_: ;
		if (!T18_) goto LA22_;
		{
			NIM_BOOL T26_;
			T26_ = (NIM_BOOL)0;
			T26_ = stackTraceAvailable__system_2747();
			if (!(T26_)) goto LA27_;
			T26_ = ((*conf).writelnHook.ClP_0 == 0);
			LA27_: ;
			if (!T26_) goto LA28_;
			writeStackTrace__system_2167();
		}
		goto LA24_;
		LA28_: ;
		{
			{
				tyArray__Re75IspeoxXy2oCZHwcRrA T35_;
				tyArray__Re75IspeoxXy2oCZHwcRrA T36_;
				NimStringDesc* T37_;
				if (!!(((*conf).writelnHook.ClP_0 == 0))) goto LA33_;
				nimZeroMem((void*)T35_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				nimZeroMem((void*)T36_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T36_[0] = copyString((*conf).command);
				T36_[1] = createDocLink__lineinfos_6(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_32));
				T35_[0] = nsuFormatOpenArray(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_31), T36_, 2);
				T35_[1] = copyString((*conf).unitSep);
				T37_ = NIM_NIL;
				T37_ = concat__msgs_415(T35_, 2);
				(*conf).writelnHook.ClE_0? (*conf).writelnHook.ClP_0(T37_, (*conf).writelnHook.ClE_0):((TM__F6BaKnf3IVC9biwXXfTyA9ag_33)((*conf).writelnHook.ClP_0))(T37_);
			}
			goto LA31_;
			LA33_: ;
			{
				if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 24))&63U)))!=0)) goto LA39_;
				{
					tyArray__Re75IspeoxXy2oCZHwcRrA T45_;
					tyArray__Re75IspeoxXy2oCZHwcRrA T46_;
					if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ) 0))&7U)))!=0)) goto LA43_;
					flushDot__msgs_17(conf);
					nimZeroMem((void*)T45_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
					nimZeroMem((void*)T46_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
					T46_[0] = copyString((*conf).command);
					T46_[1] = createDocLink__lineinfos_6(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_32));
					T45_[0] = nsuFormatOpenArray(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_31), T46_, 2);
					T45_[1] = copyString((*conf).unitSep);
					writeLine__msgs_442(stdout, T45_, 2);
					flushFile__systemZio_226(stdout);
				}
				LA43_: ;
			}
			goto LA31_;
			LA39_: ;
			{
				if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ) 1))&7U)))!=0)) goto LA48_;
				flushDot__msgs_17(conf);
				{
					tyArray__Re75IspeoxXy2oCZHwcRrA T54_;
					NimStringDesc* T55_;
					if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 22))&63U)))!=0)) goto LA52_;
					setForegroundColor__pureZterminal_387(stderr, ((tyEnum_ForegroundColor__avKgWVVKiIc89c9aKDsFLd7w) 31), NIM_FALSE);
					nimZeroMem((void*)T54_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
					T54_[0] = copyString((*conf).command);
					T54_[1] = createDocLink__lineinfos_6(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_32));
					T55_ = NIM_NIL;
					T55_ = nsuFormatOpenArray(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_31), T54_, 2);
					write__systemZio_205(stderr, T55_);
					write__systemZio_205(stderr, (*conf).unitSep);
					resetAttributes__pureZterminal_280(stderr);
					write__systemZio_205(stderr, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_14));
				}
				goto LA50_;
				LA52_: ;
				{
					tyArray__Re75IspeoxXy2oCZHwcRrA T57_;
					tyArray__Re75IspeoxXy2oCZHwcRrA T58_;
					nimZeroMem((void*)T57_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
					nimZeroMem((void*)T58_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
					T58_[0] = copyString((*conf).command);
					T58_[1] = createDocLink__lineinfos_6(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_32));
					T57_[0] = nsuFormatOpenArray(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_31), T58_, 2);
					T57_[1] = copyString((*conf).unitSep);
					writeLine__msgs_442(stderr, T57_, 2);
				}
				LA50_: ;
			}
			goto LA31_;
			LA48_: ;
			LA31_: ;
		}
		LA24_: ;
	}
	goto LA1_;
	LA22_: ;
	LA1_: ;
	exit(((NI) 1));
}
N_LIB_PRIVATE N_NIMCALL(void, handleError__msgs_880)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, NimStringDesc* s, NIM_BOOL ignoreMsg) {
	{
		if (!(msg >= ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 0) && msg <= ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 2))) goto LA3_;
		{
			if (!((*conf).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 11))) goto LA7_;
			log__msgs_796(s);
		}
		LA7_: ;
		quit__msgs_803(conf, msg);
	}
	LA3_: ;
	{
		NIM_BOOL T11_;
		NIM_BOOL T12_;
		NIM_BOOL T15_;
		NIM_BOOL T16_;
		tyObject_HSlice__OMpduBN65LLptEIzH4Rd9cw T17_;
		T11_ = (NIM_BOOL)0;
		T12_ = (NIM_BOOL)0;
		T12_ = (((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 0) <= msg);
		if (!(T12_)) goto LA13_;
		T12_ = (msg <= ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 16));
		LA13_: ;
		T11_ = T12_;
		if (T11_) goto LA14_;
		T15_ = (NIM_BOOL)0;
		T16_ = (NIM_BOOL)0;
		T17_ = dotdot___msgs_902(((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 17), ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 106));
		T16_ = contains__msgs_963(T17_, msg);
		if (!(T16_)) goto LA18_;
		T16_ = (((*conf).warningAsErrors[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (msg))- 17))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (msg))- 17))&7U)))!=0);
		LA18_: ;
		T15_ = T16_;
		if (!(T15_)) goto LA19_;
		T15_ = !(ignoreMsg);
		LA19_: ;
		T11_ = T15_;
		LA14_: ;
		if (!T11_) goto LA20_;
		(*conf).errorCounter += ((NI) 1);
		(*conf).exitcode = ((NI8) 1);
		{
			if (!((*conf).errorMax <= (*conf).errorCounter)) goto LA24_;
			{
				if (!((*conf).ideCmd == ((tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg) 0))) goto LA28_;
				quit__msgs_803(conf, msg);
			}
			LA28_: ;
		}
		goto LA22_;
		LA24_: ;
		{
			NIM_BOOL T31_;
			T31_ = (NIM_BOOL)0;
			T31_ = (eh == ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1));
			if (!(T31_)) goto LA32_;
			T31_ = !(((*conf).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 11)));
			LA32_: ;
			if (!T31_) goto LA33_;
			quit__msgs_803(conf, msg);
		}
		goto LA22_;
		LA33_: ;
		{
			if (!(eh == ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 2))) goto LA36_;
			raiseRecoverableError__lineinfos_262(s);
		}
		goto LA22_;
		LA36_: ;
		LA22_: ;
	}
	LA20_: ;
}
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw) {
	NimStringDesc* title;
	tyEnum_ForegroundColor__avKgWVVKiIc89c9aKDsFLd7w color;
	NIM_BOOL ignoreMsg;
	tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg sev;
	tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputsOld;
	NimStringDesc* kind;
	NimStringDesc* s;
	title = NIM_NIL;
	color = (tyEnum_ForegroundColor__avKgWVVKiIc89c9aKDsFLd7w)0;
	ignoreMsg = NIM_FALSE;
	sev = (tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg)0;
	errorOutputsOld = (*conf).m.errorOutputs;
	{
		if (!(msg >= ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 0) && msg <= ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 2))) goto LA3_;
		(*conf).m.errorOutputs = 3;
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		tyObject_HSlice__OMpduBN65LLptEIzH4Rd9cw T8_;
		T7_ = (NIM_BOOL)0;
		T8_ = dotdot___msgs_902(((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 17), ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 106));
		T7_ = contains__msgs_963(T8_, msg);
		if (!(T7_)) goto LA9_;
		T7_ = !((msg == ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 103)));
		LA9_: ;
		if (!T7_) goto LA10_;
		kind = reprEnum((NI)msg, (&NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_));
	}
	goto LA5_;
	LA10_: ;
	{
		kind = ((NimStringDesc*) NIM_NIL);
	}
	LA5_: ;
	switch (msg) {
	case ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 0) ... ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 16):
	{
		sev = ((tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg) 2);
		writeContext__msgs_1011(conf, info);
		title = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_15));
		color = ((tyEnum_ForegroundColor__avKgWVVKiIc89c9aKDsFLd7w) 31);
		{
			NIM_BOOL T16_;
			T16_ = (NIM_BOOL)0;
			T16_ = eqeq___msgs_1003(info, unknownLineInfo__lineinfos_284);
			if (!!(T16_)) goto LA17_;
			(*conf).m.lastError = info;
		}
		LA17_: ;
	}
	break;
	case ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 17) ... ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 71):
	{
		NIM_BOOL T20_;
		sev = ((tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg) 1);
		T20_ = (NIM_BOOL)0;
		T20_ = hasWarn__options_570(conf, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (msg)));
		ignoreMsg = !(T20_);
		{
			NIM_BOOL T23_;
			T23_ = (NIM_BOOL)0;
			T23_ = !(ignoreMsg);
			if (!(T23_)) goto LA24_;
			T23_ = (((*conf).warningAsErrors[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (msg))- 17))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (msg))- 17))&7U)))!=0);
			LA24_: ;
			if (!T23_) goto LA25_;
			title = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_15));
		}
		goto LA21_;
		LA25_: ;
		{
			title = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_16));
		}
		LA21_: ;
		{
			if (!!(ignoreMsg)) goto LA30_;
			writeContext__msgs_1011(conf, info);
		}
		LA30_: ;
		color = ((tyEnum_ForegroundColor__avKgWVVKiIc89c9aKDsFLd7w) 33);
		(*conf).warnCounter += ((NI) 1);
	}
	break;
	case ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 72) ... ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 106):
	{
		NIM_BOOL T33_;
		sev = ((tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg) 0);
		T33_ = (NIM_BOOL)0;
		T33_ = hasHint__options_530(conf, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (msg)));
		ignoreMsg = !(T33_);
		{
			NIM_BOOL T36_;
			T36_ = (NIM_BOOL)0;
			T36_ = !(ignoreMsg);
			if (!(T36_)) goto LA37_;
			T36_ = (((*conf).warningAsErrors[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (msg))- 17))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (msg))- 17))&7U)))!=0);
			LA37_: ;
			if (!T36_) goto LA38_;
			title = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_15));
		}
		goto LA34_;
		LA38_: ;
		{
			title = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_17));
		}
		LA34_: ;
		color = ((tyEnum_ForegroundColor__avKgWVVKiIc89c9aKDsFLd7w) 32);
		(*conf).hintCounter += ((NI) 1);
	}
	break;
	}
	{
		if (!isRaw) goto LA43_;
		s = arg;
	}
	goto LA41_;
	LA43_: ;
	{
		s = getMessageStr__msgs_785(msg, arg);
	}
	LA41_: ;
	{
		NimStringDesc* loc;
		NimStringDesc* kindmsg;
		if (!!(ignoreMsg)) goto LA48_;
		{
			NIM_BOOL T52_;
			NimStringDesc* T55_;
			NimStringDesc* T56_;
			T52_ = (NIM_BOOL)0;
			T52_ = eqeq___msgs_1003(info, unknownLineInfo__lineinfos_284);
			if (!!(T52_)) goto LA53_;
			T55_ = NIM_NIL;
			T56_ = NIM_NIL;
			T56_ = toFileLineCol__msgs_629(conf, info);
			T55_ = rawNewString((T56_ ? T56_->Sup.len : 0) + 1);
appendString(T55_, T56_);
appendString(T55_, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_12));
			loc = T55_;
		}
		goto LA50_;
		LA53_: ;
		{
			loc = ((NimStringDesc*) NIM_NIL);
		}
		LA50_: ;
		{
			if (!(((NI) 0) < (kind ? kind->Sup.len : 0))) goto LA60_;
			kindmsg = nsuFormatSingleElem(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_18), kind);
		}
		goto LA58_;
		LA60_: ;
		{
			kindmsg = ((NimStringDesc*) NIM_NIL);
		}
		LA58_: ;
		{
			NimStringDesc* T67_;
			if (!!(((*conf).structuredErrorHook.ClP_0 == TM__F6BaKnf3IVC9biwXXfTyA9ag_2.ClP_0 && (*conf).structuredErrorHook.ClE_0 == TM__F6BaKnf3IVC9biwXXfTyA9ag_2.ClE_0))) goto LA65_;
			T67_ = NIM_NIL;
			T67_ = rawNewString((s ? s->Sup.len : 0) + (kindmsg ? kindmsg->Sup.len : 0) + 0);
appendString(T67_, s);
appendString(T67_, kindmsg);
			(*conf).structuredErrorHook.ClE_0? (*conf).structuredErrorHook.ClP_0(conf, info, T67_, sev, (*conf).structuredErrorHook.ClE_0):((TM__F6BaKnf3IVC9biwXXfTyA9ag_19)((*conf).structuredErrorHook.ClP_0))(conf, info, T67_, sev);
		}
		LA65_: ;
		{
			NIM_BOOL T70_;
			T70_ = (NIM_BOOL)0;
			T70_ = ignoreMsgBecauseOfIdeTools__msgs_1076(conf, msg);
			if (!!(T70_)) goto LA71_;
			{
				NIM_BOOL T75_;
				T75_ = (NIM_BOOL)0;
				T75_ = (msg == ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 83));
				if (!(T75_)) goto LA76_;
				T75_ = (*conf).hintProcessingDots;
				LA76_: ;
				if (!T75_) goto LA77_;
				msgWrite__msgs_759(conf, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_20));
			}
			goto LA73_;
			LA77_: ;
			{
				{
					tyArray__yt5VDPNtUGx9cBkOVakHwdQ T84_;
					NimStringDesc* T85_;
					if (!!(((*conf).writelnHook.ClP_0 == 0))) goto LA82_;
					nimZeroMem((void*)T84_, sizeof(tyArray__yt5VDPNtUGx9cBkOVakHwdQ));
					T84_[0] = copyString(loc);
					T84_[1] = copyString(title);
					T84_[2] = copyString(s);
					T84_[3] = copyString(kindmsg);
					T84_[4] = getSurroundingSrc__msgs_1116(conf, info);
					T84_[5] = copyString((*conf).unitSep);
					T85_ = NIM_NIL;
					T85_ = concat__msgs_415(T84_, 6);
					(*conf).writelnHook.ClE_0? (*conf).writelnHook.ClP_0(T85_, (*conf).writelnHook.ClE_0):((TM__F6BaKnf3IVC9biwXXfTyA9ag_24)((*conf).writelnHook.ClP_0))(T85_);
				}
				goto LA80_;
				LA82_: ;
				{
					if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 24))&63U)))!=0)) goto LA87_;
					{
						tyArray__yt5VDPNtUGx9cBkOVakHwdQ T93_;
						if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ) 0))&7U)))!=0)) goto LA91_;
						flushDot__msgs_17(conf);
						nimZeroMem((void*)T93_, sizeof(tyArray__yt5VDPNtUGx9cBkOVakHwdQ));
						T93_[0] = copyString(loc);
						T93_[1] = copyString(title);
						T93_[2] = copyString(s);
						T93_[3] = copyString(kindmsg);
						T93_[4] = getSurroundingSrc__msgs_1116(conf, info);
						T93_[5] = copyString((*conf).unitSep);
						writeLine__msgs_442(stdout, T93_, 6);
						flushFile__systemZio_226(stdout);
					}
					LA91_: ;
				}
				goto LA80_;
				LA87_: ;
				{
					if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ) 1))&7U)))!=0)) goto LA95_;
					flushDot__msgs_17(conf);
					{
						NimStringDesc* T101_;
						if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 22))&63U)))!=0)) goto LA99_;
						setStyle__pureZterminal_313(stderr, 1);
						write__systemZio_205(stderr, loc);
						resetAttributes__pureZterminal_280(stderr);
						setForegroundColor__pureZterminal_387(stderr, color, NIM_FALSE);
						write__systemZio_205(stderr, title);
						resetAttributes__pureZterminal_280(stderr);
						write__systemZio_205(stderr, s);
						setForegroundColor__pureZterminal_387(stderr, ((tyEnum_ForegroundColor__avKgWVVKiIc89c9aKDsFLd7w) 36), NIM_FALSE);
						write__systemZio_205(stderr, kindmsg);
						resetAttributes__pureZterminal_280(stderr);
						T101_ = NIM_NIL;
						T101_ = getSurroundingSrc__msgs_1116(conf, info);
						write__systemZio_205(stderr, T101_);
						write__systemZio_205(stderr, (*conf).unitSep);
						resetAttributes__pureZterminal_280(stderr);
						write__systemZio_205(stderr, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_14));
					}
					goto LA97_;
					LA99_: ;
					{
						tyArray__yt5VDPNtUGx9cBkOVakHwdQ T103_;
						nimZeroMem((void*)T103_, sizeof(tyArray__yt5VDPNtUGx9cBkOVakHwdQ));
						T103_[0] = copyString(loc);
						T103_[1] = copyString(title);
						T103_[2] = copyString(s);
						T103_[3] = copyString(kindmsg);
						T103_[4] = getSurroundingSrc__msgs_1116(conf, info);
						T103_[5] = copyString((*conf).unitSep);
						writeLine__msgs_442(stderr, T103_, 6);
					}
					LA97_: ;
				}
				goto LA80_;
				LA95_: ;
				LA80_: ;
				{
					if (!(((*conf).mainPackageNotes[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 105)- 17))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 105)- 17))&7U)))!=0)) goto LA106_;
					{
						tyArray__sMpvt1sOxOJ3LFGulnbeMQ T112_;
						NimStringDesc* T113_;
						if (!!(((*conf).writelnHook.ClP_0 == 0))) goto LA110_;
						nimZeroMem((void*)T112_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
						T112_[0] = toFileLineCol__msgs_625(info2);
						T112_[1] = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_25));
						T112_[2] = nsuFormatSingleElem(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_18), ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_26));
						T112_[3] = copyString((*conf).unitSep);
						T113_ = NIM_NIL;
						T113_ = concat__msgs_415(T112_, 4);
						(*conf).writelnHook.ClE_0? (*conf).writelnHook.ClP_0(T113_, (*conf).writelnHook.ClE_0):((TM__F6BaKnf3IVC9biwXXfTyA9ag_27)((*conf).writelnHook.ClP_0))(T113_);
					}
					goto LA108_;
					LA110_: ;
					{
						if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 24))&63U)))!=0)) goto LA115_;
						{
							tyArray__sMpvt1sOxOJ3LFGulnbeMQ T121_;
							if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ) 0))&7U)))!=0)) goto LA119_;
							flushDot__msgs_17(conf);
							nimZeroMem((void*)T121_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
							T121_[0] = toFileLineCol__msgs_625(info2);
							T121_[1] = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_25));
							T121_[2] = nsuFormatSingleElem(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_18), ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_26));
							T121_[3] = copyString((*conf).unitSep);
							writeLine__msgs_442(stdout, T121_, 4);
							flushFile__systemZio_226(stdout);
						}
						LA119_: ;
					}
					goto LA108_;
					LA115_: ;
					{
						if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ) 1))&7U)))!=0)) goto LA123_;
						flushDot__msgs_17(conf);
						{
							NimStringDesc* T129_;
							NimStringDesc* T130_;
							if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 22))&63U)))!=0)) goto LA127_;
							setStyle__pureZterminal_313(stderr, 1);
							T129_ = NIM_NIL;
							T129_ = toFileLineCol__msgs_625(info2);
							write__systemZio_205(stderr, T129_);
							resetAttributes__pureZterminal_280(stderr);
							write__systemZio_205(stderr, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_25));
							setForegroundColor__pureZterminal_387(stderr, ((tyEnum_ForegroundColor__avKgWVVKiIc89c9aKDsFLd7w) 36), NIM_FALSE);
							T130_ = NIM_NIL;
							T130_ = nsuFormatSingleElem(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_18), ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_26));
							write__systemZio_205(stderr, T130_);
							resetAttributes__pureZterminal_280(stderr);
							write__systemZio_205(stderr, (*conf).unitSep);
							resetAttributes__pureZterminal_280(stderr);
							write__systemZio_205(stderr, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_14));
						}
						goto LA125_;
						LA127_: ;
						{
							tyArray__sMpvt1sOxOJ3LFGulnbeMQ T132_;
							nimZeroMem((void*)T132_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
							T132_[0] = toFileLineCol__msgs_625(info2);
							T132_[1] = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_25));
							T132_[2] = nsuFormatSingleElem(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_18), ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_26));
							T132_[3] = copyString((*conf).unitSep);
							writeLine__msgs_442(stderr, T132_, 4);
						}
						LA125_: ;
					}
					goto LA108_;
					LA123_: ;
					LA108_: ;
				}
				LA106_: ;
			}
			LA73_: ;
		}
		LA71_: ;
	}
	LA48_: ;
	handleError__msgs_880(conf, msg, eh, s, ignoreMsg);
	{
		if (!(msg >= ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 0) && msg <= ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 2))) goto LA135_;
		(*conf).m.errorOutputs = errorOutputsOld;
	}
	LA135_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, msgWriteln__msgs_657)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* s, tySet_tyEnum_MsgFlag__20vXBZGIzyW7fngd9aGsclQ flags) {
	NimStringDesc* sep;
	{
		if (!!(((flags &((NU8)1<<((NU)(((tyEnum_MsgFlag__20vXBZGIzyW7fngd9aGsclQ) 2))&7U)))!=0))) goto LA3_;
		sep = (*conf).unitSep;
	}
	goto LA1_;
	LA3_: ;
	{
		sep = ((NimStringDesc*) NIM_NIL);
	}
	LA1_: ;
	{
		NIM_BOOL T8_;
		NimStringDesc* T12_;
		T8_ = (NIM_BOOL)0;
		T8_ = !(((*conf).writelnHook.ClP_0 == 0));
		if (!(T8_)) goto LA9_;
		T8_ = !(((flags &((NU8)1<<((NU)(((tyEnum_MsgFlag__20vXBZGIzyW7fngd9aGsclQ) 1))&7U)))!=0));
		LA9_: ;
		if (!T8_) goto LA10_;
		T12_ = NIM_NIL;
		T12_ = rawNewString((s ? s->Sup.len : 0) + (sep ? sep->Sup.len : 0) + 0);
appendString(T12_, s);
appendString(T12_, sep);
		(*conf).writelnHook.ClE_0? (*conf).writelnHook.ClP_0(T12_, (*conf).writelnHook.ClE_0):((TM__F6BaKnf3IVC9biwXXfTyA9ag_34)((*conf).writelnHook.ClP_0))(T12_);
	}
	goto LA6_;
	LA10_: ;
	{
		NIM_BOOL T14_;
		T14_ = (NIM_BOOL)0;
		T14_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 24))&63U)))!=0);
		if (T14_) goto LA15_;
		T14_ = ((flags &((NU8)1<<((NU)(((tyEnum_MsgFlag__20vXBZGIzyW7fngd9aGsclQ) 0))&7U)))!=0);
		LA15_: ;
		if (!T14_) goto LA16_;
		{
			tyArray__nHXaesL0DJZHyVS07ARPRA T22_;
			if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ) 0))&7U)))!=0)) goto LA20_;
			flushDot__msgs_17(conf);
			write__systemZio_205(stdout, s);
			nimZeroMem((void*)T22_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
			T22_[0] = copyString(sep);
			writeLine__msgs_442(stdout, T22_, 1);
			flushFile__systemZio_226(stdout);
		}
		LA20_: ;
	}
	goto LA6_;
	LA16_: ;
	{
		{
			tyArray__nHXaesL0DJZHyVS07ARPRA T28_;
			if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ) 1))&7U)))!=0)) goto LA26_;
			flushDot__msgs_17(conf);
			write__systemZio_205(stderr, s);
			nimZeroMem((void*)T28_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
			T28_[0] = copyString(sep);
			writeLine__msgs_442(stderr, T28_, 1);
		}
		LA26_: ;
	}
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, listWarnings__msgs_1485)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	msgWriteln__msgs_657(conf, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_35), 4);
	{
		tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ aX60gensym129_;
		NI res;
		aX60gensym129_ = (tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ)0;
		res = ((NI) 17);
		{
			while (1) {
				tyArray__Re75IspeoxXy2oCZHwcRrA T4_;
				NimStringDesc* T10_;
				if (!(res <= ((NI) 71))) goto LA3;
				aX60gensym129_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) (res));
				nimZeroMem((void*)T4_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				{
					if (!(((*conf).notes[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (aX60gensym129_))- 17))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (aX60gensym129_))- 17))&7U)))!=0)) goto LA7_;
					T4_[0] = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_37));
				}
				goto LA5_;
				LA7_: ;
				{
					T4_[0] = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_12));
				}
				LA5_: ;
				T4_[1] = reprEnum((NI)aX60gensym129_, (&NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_));
				T10_ = NIM_NIL;
				T10_ = nsuFormatOpenArray(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_36), T4_, 2);
				msgWriteln__msgs_657(conf, T10_, 4);
				res += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, listHints__msgs_1506)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	msgWriteln__msgs_657(conf, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_38), 4);
	{
		tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ aX60gensym131_;
		NI res;
		aX60gensym131_ = (tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ)0;
		res = ((NI) 72);
		{
			while (1) {
				tyArray__Re75IspeoxXy2oCZHwcRrA T4_;
				NimStringDesc* T10_;
				if (!(res <= ((NI) 106))) goto LA3;
				aX60gensym131_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) (res));
				nimZeroMem((void*)T4_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				{
					if (!(((*conf).notes[(NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (aX60gensym131_))- 17))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) (aX60gensym131_))- 17))&7U)))!=0)) goto LA7_;
					T4_[0] = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_37));
				}
				goto LA5_;
				LA7_: ;
				{
					T4_[0] = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_12));
				}
				LA5_: ;
				T4_[1] = reprEnum((NI)aX60gensym131_, (&NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_));
				T10_ = NIM_NIL;
				T10_ = nsuFormatOpenArray(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_36), T4_, 2);
				msgWriteln__msgs_657(conf, T10_, 4);
				res += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, msgQuit__msgs_452)(NI8 x) {
	exit(((NI) (x)));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, newLineInfo__msgs_391)(NI32 fileInfoIdx, NI line, NI col) {
	tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw result;
	nimZeroMem((void*)(&result), sizeof(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw));
	result.fileIndex = fileInfoIdx;
	{
		if (!(line < ((NI) 65535))) goto LA3_;
		result.line = ((NU16) (line));
	}
	goto LA1_;
	LA3_: ;
	{
		result.line = ((NU16) 65535);
	}
	LA1_: ;
	{
		if (!(col < ((NI) 32767))) goto LA8_;
		result.col = ((NI16) (col));
	}
	goto LA6_;
	LA8_: ;
	{
		result.col = ((NI16) -1);
	}
	LA6_: ;
	return result;
}
static N_INLINE(void, shallow__system_7426)(NimStringDesc** s) {
	TGenericSeq* s_2;
	s_2 = ((TGenericSeq*) ((*s)));
	{
		NimStringDesc* T5_;
		if (!(s_2 == ((TGenericSeq*) NIM_NIL))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = mnewString(((NI) 0));
		s_2 = ((TGenericSeq*) (T5_));
	}
	LA3_: ;
	{
		if (!((NI)((*s_2).reserved & ((NI) 1073741824)) == ((NI) 0))) goto LA8_;
		(*s_2).reserved = (NI)((*s_2).reserved | ((NI) (-2147483647 -1)));
	}
	LA8_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, canonicalCase__msgs_67)(NimStringDesc** path) {
}
static N_INLINE(NF, toFloat__system_1702)(NI i) {
	NF result;
	result = (NF)0;
	result = ((NF) (i));
	return result;
}
static N_INLINE(void, toCChar__msgs_47)(NIM_CHAR c, NimStringDesc** result) {
	switch (((NU8)(c))) {
	case 0 ... 31:
	case 127 ... 255:
	{
		NimStringDesc* T2_;
		unsureAsgnRef((void**) (&(*result)), addChar((*result), 92));
		T2_ = NIM_NIL;
		T2_ = nsuToOctal(c);
		unsureAsgnRef((void**) (&(*result)), resizeString((*result), (T2_ ? T2_->Sup.len : 0) + 0));
appendString((*result), T2_);
	}
	break;
	case 39:
	case 34:
	case 92:
	case 63:
	{
		unsureAsgnRef((void**) (&(*result)), addChar((*result), 92));
		unsureAsgnRef((void**) (&(*result)), addChar((*result), c));
	}
	break;
	default:
	{
		unsureAsgnRef((void**) (&(*result)), addChar((*result), c));
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, makeCString__msgs_50)(NimStringDesc* s) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NimStringDesc* res;
	NF T1_;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T5_;
	result = NIM_NIL;
	result = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	T1_ = (NF)0;
	T1_ = toFloat__system_1702((s ? s->Sup.len : 0));
	res = rawNewString(((NI) ((NI)(((NI) (((NF)(T1_) * (NF)(1.1)))) + ((NI) 1)))));
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_40));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (s ? s->Sup.len : 0);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				toCChar__msgs_47(s->data[i], (&res));
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	res = addChar(res, 34);
	T5_ = NIM_NIL;
	T5_ = rope__ropes_109(res);
	add__ropes_159(&result, T5_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, newFileInfo__msgs_59)(NimStringDesc* fullPath, NimStringDesc* projPath, tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w* Result) {
	unsureAsgnRef((void**)&(*Result).fullPath, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).projPath, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).shortName, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).quotedName, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).quotedFullName, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).lines, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).dirtyFile, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).hash, NIM_NIL);
	(*Result).dirty = 0;
	unsureAsgnRef((void**) (&(*Result).fullPath), copyString(fullPath));
	unsureAsgnRef((void**) (&(*Result).projPath), copyString(projPath));
	unsureAsgnRef((void**) (&(*Result).shortName), nosextractFilename(fullPath));
	unsureAsgnRef((void**) (&(*Result).quotedName), makeCString__msgs_50((*Result).shortName));
	unsureAsgnRef((void**) (&(*Result).quotedFullName), makeCString__msgs_50(fullPath));
	unsureAsgnRef((void**) (&(*Result).lines), NIM_NIL);
}
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__msgs_127)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename, NIM_BOOL* isKnownFile) {
	NI32 result;
	NimStringDesc* volatile canon;
	NIM_BOOL pseudoPath;
	TSafePoint TM__F6BaKnf3IVC9biwXXfTyA9ag_39;
	NimStringDesc* canon2;
	result = (NI32)0;
	canon = NIM_NIL;
	pseudoPath = NIM_FALSE;
	pushSafePoint(&TM__F6BaKnf3IVC9biwXXfTyA9ag_39);
	TM__F6BaKnf3IVC9biwXXfTyA9ag_39.status = setjmp(TM__F6BaKnf3IVC9biwXXfTyA9ag_39.context);
	if (TM__F6BaKnf3IVC9biwXXfTyA9ag_39.status == 0) {
	canon = canonicalizePath__options_4119(conf, filename);
	shallow__system_7426((&canon));
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIoserror__THeHlGxHorUQ17FON5jY0g_))) {
			TM__F6BaKnf3IVC9biwXXfTyA9ag_39.status = 0;
			canon = copyString(filename);
			pseudoPath = NIM_TRUE;
			popCurrentException();
		}
	}
	if (TM__F6BaKnf3IVC9biwXXfTyA9ag_39.status != 0) reraiseException();
	canon2 = NIM_NIL;
	forceCopy__strutils50_10((&canon2), canon);
	canonicalCase__msgs_67((&canon2));
	{
		NIM_BOOL T5_;
		NI32* T8_;
		T5_ = (NIM_BOOL)0;
		T5_ = hasKey__msgs_114((*conf).m.filenameToIndexTbl, canon2);
		if (!T5_) goto LA6_;
		(*isKnownFile) = NIM_TRUE;
		T8_ = (NI32*)0;
		T8_ = X5BX5D___msgs_233((&(*conf).m.filenameToIndexTbl), canon2);
		result = (*T8_);
	}
	goto LA3_;
	LA6_: ;
	{
		NI T10_;
		NimStringDesc* T11_;
		tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w T17_;
		NI T18_;
		(*isKnownFile) = NIM_FALSE;
		T10_ = ((*conf).m.fileInfos ? (*conf).m.fileInfos->Sup.len : 0);
		result = ((NI32) (T10_));
		T11_ = NIM_NIL;
		{
			if (!pseudoPath) goto LA14_;
			T11_ = copyString(filename);
		}
		goto LA12_;
		LA14_: ;
		{
			T11_ = relativeTo__pathutils_133(canon, (*conf).projectPath, 47);
		}
		LA12_: ;
		nimZeroMem((void*)(&T17_), sizeof(tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w));
		newFileInfo__msgs_59(canon, T11_, (&T17_));
		asgnRef((void**) (&(*conf).m.fileInfos), (tySequence__8rKxBHaz7QqNR9a4WIZqqqQ*) incrSeqV3((TGenericSeq*)((*conf).m.fileInfos), (&NTIseqLtfileinfoT__8rKxBHaz7QqNR9a4WIZqqqQ_)));
		T18_ = (*conf).m.fileInfos->Sup.len++;
		genericAssign((void*)(&(*conf).m.fileInfos->data[T18_]), (void*)(&T17_), (&NTItfileinfo__2PBRRPxvvEH2sQ9cRi19bh7w_));
		X5BX5Deq___lineinfos_391((&(*conf).m.filenameToIndexTbl), canon2, result);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__msgs_376)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename) {
	NI32 result;
	NIM_BOOL dummy;
	result = (NI32)0;
	dummy = (NIM_BOOL)0;
	result = fileInfoIdx__msgs_127(conf, filename, (&dummy));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setDirtyFile__msgs_556)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx, NimStringDesc* filename) {
	NimStringDesc* T1_;
	T1_ = NIM_NIL;
	T1_ = (*conf).m.fileInfos->data[fileIdx].dirtyFile; (*conf).m.fileInfos->data[fileIdx].dirtyFile = copyStringRC1(filename);
	if (T1_) nimGCunrefNoCycle(T1_);
	asgnRef((void**) (&(*conf).m.fileInfos->data[fileIdx].lines), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) setLengthSeqV2(((*conf).m.fileInfos->data[fileIdx].lines)?&((*conf).m.fileInfos->data[fileIdx].lines)->Sup:NIM_NIL, (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_), ((NI) 0)));
}
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_1441)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2) {
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*conf).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 11));
		if (!(T3_)) goto LA4_;
		T3_ = ((*conf).structuredErrorHook.ClP_0 == 0);
		LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	writeContext__msgs_1011(conf, info);
	liMessage__msgs_1128(conf, info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 2), errMsg, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), info2, NIM_FALSE);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___msgs_634)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = toFileLineCol__msgs_629(conf, info);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getHash__msgs_574)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = (*conf).m.fileInfos->data[fileIdx].hash;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setHash__msgs_567)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx, NimStringDesc* hash) {
	asgnRef((void**) (&(*conf).m.fileInfos->data[fileIdx].hash), hash);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, uniqueModuleName__msgs_1521)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fid) {
	NimStringDesc* result;
	NimStringDesc* path;
	NimStringDesc* rel;
	NI trunc_1;
	result = NIM_NIL;
	path = toFullPath__msgs_548(conf, fid);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nsuStartsWith(path, (*conf).libpath);
		if (!T3_) goto LA4_;
		rel = relativeTo__pathutils_133(path, (*conf).libpath, 47);
	}
	goto LA1_;
	LA4_: ;
	{
		rel = relativeTo__pathutils_133(path, (*conf).projectPath, 47);
	}
	LA1_: ;
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = nsuEndsWith(rel, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_41));
		if (!T9_) goto LA10_;
		trunc_1 = (NI)((rel ? rel->Sup.len : 0) - ((NI) 4));
	}
	goto LA7_;
	LA10_: ;
	{
		trunc_1 = (rel ? rel->Sup.len : 0);
	}
	LA7_: ;
	result = rawNewString(((NI) (trunc_1)));
	{
		NI i;
		NI i_2;
		i = (NI)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				NIM_CHAR c;
				if (!(i_2 < trunc_1)) goto LA15;
				i = i_2;
				c = rel->data[i];
				switch (((NU8)(c))) {
				case 97 ... 122:
				{
					result = addChar(result, c);
				}
				break;
				case 47:
				{
					result = addChar(result, 90);
				}
				break;
				case 46:
				{
					result = addChar(result, 79);
				}
				break;
				default:
				{
					addInt__stdZprivateZdigitsutils_189((&result), ((NU8)(c)));
				}
				break;
				}
				i_2 += ((NI) 1);
			} LA15: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pushInfoContext__msgs_500)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* detail) {
	tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ T1_;
	NI T2_;
	NimStringDesc* T3_;
	nimZeroMem((void*)(&T1_), sizeof(tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ));
	T1_.Field0 = info;
	T1_.Field1 = copyString(detail);
	asgnRef((void**) (&(*conf).m.msgContext), (tySequence__mIo9bZUsotCEUUtEGNhYmaA*) incrSeqV3((TGenericSeq*)((*conf).m.msgContext), (&NTIseqLtupleLinfo58tlineinfo_detail58stringTT__mIo9bZUsotCEUUtEGNhYmaA_)));
	T2_ = (*conf).m.msgContext->Sup.len++;
	(*conf).m.msgContext->data[T2_].Field0 = T1_.Field0;
	T3_ = NIM_NIL;
	T3_ = (*conf).m.msgContext->data[T2_].Field1; (*conf).m.msgContext->data[T2_].Field1 = copyStringRC1(T1_.Field1);
	if (T3_) nimGCunrefNoCycle(T3_);
}
N_LIB_PRIVATE N_NIMCALL(void, popInfoContext__msgs_517)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NI T1_;
	T1_ = ((*conf).m.msgContext ? (*conf).m.msgContext->Sup.len : 0);
	asgnRef((void**) (&(*conf).m.msgContext), (tySequence__mIo9bZUsotCEUUtEGNhYmaA*) setLengthSeqV2(((*conf).m.msgContext)?&((*conf).m.msgContext)->Sup:NIM_NIL, (&NTIseqLtupleLinfo58tlineinfo_detail58stringTT__mIo9bZUsotCEUUtEGNhYmaA_), ((NI) ((NI)(T1_ - ((NI) 1))))));
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exactEquals__msgs_1007)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw a, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw b) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = (a.fileIndex == b.fileIndex);
	if (!(T2_)) goto LA3_;
	T2_ = (a.line == b.line);
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = (a.col == b.col);
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestWriteln__msgs_431)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* s) {
	{
		if (!(((*conf).m.errorOutputs &((NU8)1<<((NU)(((tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ) 0))&7U)))!=0)) goto LA3_;
		{
			tyArray__nHXaesL0DJZHyVS07ARPRA T9_;
			if (!((*conf).writelnHook.ClP_0 == 0)) goto LA7_;
			nimZeroMem((void*)T9_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
			T9_[0] = copyString(s);
			writeLine__msgs_442(stdout, T9_, 1);
			flushFile__systemZio_226(stdout);
		}
		goto LA5_;
		LA7_: ;
		{
			(*conf).writelnHook.ClE_0? (*conf).writelnHook.ClP_0(s, (*conf).writelnHook.ClE_0):((TM__F6BaKnf3IVC9biwXXfTyA9ag_42)((*conf).writelnHook.ClP_0))(s);
		}
		LA5_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestQuit__msgs_456)(void) {
	tyObject_ESuggestDone__0sxcG9bses4KEF5Ub8L9ae1Q* T1_;
	NimStringDesc* T2_;
	T1_ = NIM_NIL;
	T1_ = (tyObject_ESuggestDone__0sxcG9bses4KEF5Ub8L9ae1Q*) newObj((&NTIrefesuggestdone__NT9aUkpr32D3T9aXH5k1dBXg_), sizeof(tyObject_ESuggestDone__0sxcG9bses4KEF5Ub8L9ae1Q));
	(*T1_).Sup.Sup.Sup.Sup.m_type = (&NTIesuggestdone__0sxcG9bses4KEF5Ub8L9ae1Q_);
	(*T1_).Sup.Sup.Sup.name = "ESuggestDone";
	T2_ = NIM_NIL;
	T2_ = (*T1_).Sup.Sup.Sup.message; (*T1_).Sup.Sup.Sup.message = copyStringRC1(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_43));
	if (T2_) nimGCunrefNoCycle(T2_);
	asgnRef((void**) (&(*T1_).Sup.Sup.Sup.parent), ((Exception*) NIM_NIL));
	raiseExceptionEx((Exception*)T1_, "ESuggestDone", "suggestQuit", "msgs.nim", 167);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, formatMsg__msgs_1121)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg) {
	NimStringDesc* result;
	NimStringDesc* title;
	NimStringDesc* T4_;
	NimStringDesc* T5_;
	NimStringDesc* T6_;
	result = NIM_NIL;
	switch (msg) {
	case ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 17) ... ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 71):
	{
		title = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_16));
	}
	break;
	case ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 72) ... ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 106):
	{
		title = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_17));
	}
	break;
	default:
	{
		title = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_15));
	}
	break;
	}
	T4_ = NIM_NIL;
	T5_ = NIM_NIL;
	T5_ = toFileLineCol__msgs_629(conf, info);
	T6_ = NIM_NIL;
	T6_ = getMessageStr__msgs_785(msg, arg);
	T4_ = rawNewString((T5_ ? T5_->Sup.len : 0) + (title ? title->Sup.len : 0) + (T6_ ? T6_->Sup.len : 0) + 1);
appendString(T4_, T5_);
appendString(T4_, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_12));
appendString(T4_, title);
appendString(T4_, T6_);
	result = T4_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__msgs_386)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename) {
	NI32 result;
	NIM_BOOL dummy;
	NimStringDesc* T1_;
	result = (NI32)0;
	dummy = (NIM_BOOL)0;
	T1_ = NIM_NIL;
	T1_ = nosexpandFilename(filename);
	result = fileInfoIdx__msgs_127(conf, T1_, (&dummy));
	return result;
}
static N_INLINE(NIM_BOOL, lteqpercent___system_985)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) <= (NU32)(((NU) (y))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, getInfoContext__msgs_526)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI index) {
	tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw result;
	NI i;
	nimZeroMem((void*)(&result), sizeof(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw));
	{
		NI T5_;
		if (!(index < ((NI) 0))) goto LA3_;
		T5_ = ((*conf).m.msgContext ? (*conf).m.msgContext->Sup.len : 0);
		i = (NI)(T5_ + index);
	}
	goto LA1_;
	LA3_: ;
	{
		i = index;
	}
	LA1_: ;
	{
		NI T9_;
		NIM_BOOL T10_;
		T9_ = ((*conf).m.msgContext ? (*conf).m.msgContext->Sup.len : 0);
		T10_ = (NIM_BOOL)0;
		T10_ = lteqpercent___system_985(T9_, i);
		if (!T10_) goto LA11_;
		result = unknownLineInfo__lineinfos_284;
	}
	goto LA7_;
	LA11_: ;
	{
		result = (*conf).m.msgContext->data[i].Field0;
	}
	LA7_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getInfoContextLen__msgs_486)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NI result;
	NI T1_;
{	result = (NI)0;
	T1_ = ((*conf).m.msgContext ? (*conf).m.msgContext->Sup.len : 0);
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setInfoContextLen__msgs_493)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI L) {
	asgnRef((void**) (&(*conf).m.msgContext), (tySequence__mIo9bZUsotCEUUtEGNhYmaA*) setLengthSeqV2(((*conf).m.msgContext)?&((*conf).m.msgContext)->Sup:NIM_NIL, (&NTIseqLtupleLinfo58tlineinfo_detail58stringTT__mIo9bZUsotCEUUtEGNhYmaA_), ((NI) (L))));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, quotedFilename__msgs_1473)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw i) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	result = NIM_NIL;
	{
		if (!(i.fileIndex < ((NI32) 0))) goto LA3_;
		result = makeCString__msgs_50(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_7));
	}
	goto LA1_;
	LA3_: ;
	{
		if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 31))&63U)))!=0)) goto LA6_;
		result = (*conf).m.fileInfos->data[i.fileIndex].quotedFullName;
	}
	goto LA1_;
	LA6_: ;
	{
		result = (*conf).m.fileInfos->data[i.fileIndex].quotedName;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isEmpty__options_4084)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genSuccessX__msgs_1537)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	NimStringDesc* mem;
	NimStringDesc* T1_;
	NI T2_;
	NimStringDesc* T3_;
	NimStringDesc* loc;
	NimStringDesc* build;
	NimStringDesc* flags;
	NimStringDesc* sec;
	NF T50_;
	NimStringDesc* project;
	NimStringDesc* output;
	NimStringDesc* argX60gensym143_;
	NimStringDesc* T73_;
	tyArray__ucDUDWdKfioXQrN9bCbG29bg T74_;
	T1_ = NIM_NIL;
	T2_ = (NI)0;
	T2_ = getMaxMem__system_5236();
	T3_ = NIM_NIL;
	T3_ = formatSize__pureZstrutils_1967(((NI64) (T2_)), 46, ((tyEnum_BinaryPrefixMode__9aq8p9cHh4TxM4kldzuu2GZA) 0), NIM_FALSE);
	T1_ = rawNewString((T3_ ? T3_->Sup.len : 0) + 8);
appendString(T1_, T3_);
appendString(T1_, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_44));
	mem = T1_;
	loc = dollar___systemZdollars_3((*conf).linesCompiled);
	build = ((NimStringDesc*) NIM_NIL);
	flags = ((NimStringDesc*) NIM_NIL);
	{
		if (!((124 &((NU32)1<<((NU)((*conf).cmd)&31U)))!=0)) goto LA6_;
		{
			NimStringDesc* T12_;
			if (!!(((*conf).backend == ((tyEnum_TBackend__zoooocqvga73vZuhGAAy6A) 3)))) goto LA10_;
			T12_ = NIM_NIL;
			T12_ = nsuFormatSingleElem(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_45), reprEnum((NI)(*conf).selectedGC, (&NTItgcmode__yHeclYqeKaCEfMHNbcWn4w_)));
			build = resizeString(build, (T12_ ? T12_->Sup.len : 0) + 0);
appendString(build, T12_);
			{
				if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 23))&63U)))!=0)) goto LA15_;
				build = resizeString(build, 13);
appendString(build, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_46));
			}
			LA15_: ;
			build = resizeString(build, 5);
appendString(build, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_47));
			{
				if (!(((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 15))&31U)))!=0)) goto LA19_;
				build = resizeString(build, 5);
appendString(build, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_48));
			}
			goto LA17_;
			LA19_: ;
			{
				if (!(((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ) 16))&31U)))!=0)) goto LA22_;
				build = resizeString(build, 4);
appendString(build, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_49));
			}
			goto LA17_;
			LA22_: ;
			{
				build = resizeString(build, 54);
appendString(build, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_50));
			}
			LA17_: ;
			{
				NIM_BOOL T27_;
				T27_ = (NIM_BOOL)0;
				T27_ = isDefined__options_2292(conf, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_51));
				if (!T27_) goto LA28_;
				flags = resizeString(flags, 10);
appendString(flags, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_52));
			}
			goto LA25_;
			LA28_: ;
			{
				NIM_BOOL T31_;
				T31_ = (NIM_BOOL)0;
				T31_ = isDefined__options_2292(conf, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_53));
				if (!T31_) goto LA32_;
				flags = resizeString(flags, 11);
appendString(flags, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_54));
			}
			goto LA25_;
			LA32_: ;
			LA25_: ;
		}
		goto LA8_;
		LA10_: ;
		{
			build = resizeString(build, 5);
appendString(build, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_47));
			{
				NIM_BOOL T37_;
				T37_ = (NIM_BOOL)0;
				T37_ = isDefined__options_2292(conf, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_51));
				if (!T37_) goto LA38_;
				build = resizeString(build, 5);
appendString(build, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_48));
				flags = resizeString(flags, 10);
appendString(flags, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_52));
			}
			goto LA35_;
			LA38_: ;
			{
				NIM_BOOL T41_;
				T41_ = (NIM_BOOL)0;
				T41_ = isDefined__options_2292(conf, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_53));
				if (!T41_) goto LA42_;
				build = resizeString(build, 5);
appendString(build, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_48));
				flags = resizeString(flags, 11);
appendString(flags, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_54));
			}
			goto LA35_;
			LA42_: ;
			{
				build = resizeString(build, 54);
appendString(build, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_50));
			}
			LA35_: ;
		}
		LA8_: ;
		{
			NimStringDesc* T49_;
			if (!(((NI) 0) < (flags ? flags->Sup.len : 0))) goto LA47_;
			T49_ = NIM_NIL;
			T49_ = rawNewString((flags ? flags->Sup.len : 0) + 10);
appendString(T49_, ((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_55));
appendString(T49_, flags);
			build = resizeString(build, (T49_ ? T49_->Sup.len : 0) + 0);
appendString(build, T49_);
		}
		LA47_: ;
	}
	LA6_: ;
	T50_ = (NF)0;
	T50_ = epochTime__pureZtimes_3608();
	sec = nsuformatFloat(((NF)(T50_) - (NF)((*conf).lastCmdTime)), ((tyEnum_FloatFormatMode__alaW5GAGZvqS9bWFnNLXFuA) 1), ((NI) 3), 46);
	{
		if (!((*conf).filenameOption == ((tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w) 0))) goto LA53_;
		project = dollar___options_4370((*conf).projectFull);
	}
	goto LA51_;
	LA53_: ;
	{
		project = (*conf).projectName;
	}
	LA51_: ;
	output = NIM_NIL;
	{
		NIM_BOOL T58_;
		T58_ = (NIM_BOOL)0;
		T58_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 4))&63U)))!=0);
		if (!(T58_)) goto LA59_;
		T58_ = !(((*conf).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 26)));
		LA59_: ;
		if (!T58_) goto LA60_;
		output = dollar___options_4370((*conf).jsonBuildFile);
	}
	goto LA56_;
	LA60_: ;
	{
		NIM_BOOL T63_;
		T63_ = (NIM_BOOL)0;
		T63_ = isEmpty__options_4084((*conf).outFile);
		if (!(T63_)) goto LA64_;
		T63_ = !(((71098492 &((NU32)1<<((NU)((*conf).cmd)&31U)))!=0));
		LA64_: ;
		if (!T63_) goto LA65_;
		output = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_56));
	}
	goto LA56_;
	LA65_: ;
	{
		NimStringDesc* T68_;
		T68_ = NIM_NIL;
		T68_ = absOutFile__options_4073(conf);
		output = dollar___options_4370(T68_);
	}
	LA56_: ;
	{
		if (!!(((*conf).filenameOption == ((tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w) 0)))) goto LA71_;
		output = nosextractFilename(output);
	}
	LA71_: ;
	T73_ = NIM_NIL;
	T73_ = msgKindToString__msgs_782(((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 73));
	nimZeroMem((void*)T74_, sizeof(tyArray__ucDUDWdKfioXQrN9bCbG29bg));
	T74_[0] = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_57));
	T74_[1] = copyString(build);
	T74_[2] = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_58));
	T74_[3] = copyString(loc);
	T74_[4] = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_59));
	T74_[5] = copyString(sec);
	T74_[6] = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_60));
	T74_[7] = copyString(mem);
	T74_[8] = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_61));
	T74_[9] = copyString(project);
	T74_[10] = copyString(((NimStringDesc*) &TM__F6BaKnf3IVC9biwXXfTyA9ag_62));
	T74_[11] = copyString(output);
	argX60gensym143_ = nsuFormatOpenArray(T73_, T74_, 12);
	liMessage__msgs_1128(conf, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 73), argX60gensym143_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__F6BaKnf3IVC9biwXXfTyA9ag_63, NIM_TRUE);
}
